#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-base
version:              0.4.6.1
visibility:           public
id:                   transformers-base-0.4.6.1-KXwasGWOatO2Aiqs7lyf9n
key:                  transformers-base-0.4.6.1-KXwasGWOatO2Aiqs7lyf9n
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  425f12dea896de4d6794e3faf52ebce2
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6.1-KXwasGWOatO2Aiqs7lyf9n
depends:
    base-4.18.2.1 base-orphans-0.9.3-6eHtw3ngQEKHEGQPUmUnCL stm-2.5.1.0
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

